<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://rescuethemes.com
 * @since      1.0.0
 *
 * @package    Nutritionwp
 * @subpackage Nutritionwp/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Nutritionwp
 * @subpackage Nutritionwp/admin
 * @author     rescuethemes.com <plugins@rescuethemes.com>
 */
class Nutritionwp_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}
	
	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Nutritionwp_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Nutritionwp_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/nutritionwp-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Nutritionwp_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Nutritionwp_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/nutritionwp-admin.js', array( 'jquery' ), $this->version, false );

	}

	
	/**
	 * Add thumbnail images.
	 * 
	 * @since	1.0.0
	 * @access	public
	 * @static
	 * @return	void
	 */
	public static function add_images() {
		
		add_image_size( 'nwp-recipe-thumbnail', 370, 250 ); 
		add_image_size( 'nwp-recipe-medium', 700, 460, true ); 
		add_image_size( 'nwp-recipe-large', 1024, 680, true ); 
		
	}
	/**
	 * Register the Custom Post Type for the admin area.
	 *
	 * @since	1.0.0
	 * @static
	 * @return	void
	 */
	public static function register_cpt() {

		$cap_type 	= 'post';
		$plural 	= 'Recipes';
		$single 	= 'Recipe';
		$cpt_name 	= 'nutritionwp-recipe';

		$opts['can_export']								= TRUE;
		$opts['capability_type']						= $cap_type;
		$opts['description']							= '';
		$opts['exclude_from_search']					= FALSE;
		$opts['has_archive']							= TRUE;
		$opts['hierarchical']							= FALSE;
		$opts['map_meta_cap']							= TRUE;
		$opts['menu_icon']								= plugin_dir_url( __FILE__ ) . '/img/nutritionwp.png';
		$opts['menu_position']							= 25;
		$opts['public']									= TRUE;
		$opts['publicly_querable']						= TRUE;
		$opts['query_var']								= TRUE;
		$opts['register_meta_box_cb']					= '';
		$opts['rewrite']								= FALSE;
		$opts['excerpt']								= TRUE;
		$opts['show_in_admin_bar']						= TRUE;
		$opts['show_in_menu']							= TRUE;
		$opts['show_in_nav_menu']						= TRUE;
		$opts['show_ui']								= TRUE;
		$opts['supports']								= array( 'title', 'editor', 'thumbnail', 'excerpt', 'comments', 'revisions', 'author' );
		$opts['taxonomies']								= array();

		$opts['capabilities']['delete_others_posts']	= "delete_others_{$cap_type}s";
		$opts['capabilities']['delete_post']			= "delete_{$cap_type}";
		$opts['capabilities']['delete_posts']			= "delete_{$cap_type}s";
		$opts['capabilities']['delete_private_posts']	= "delete_private_{$cap_type}s";
		$opts['capabilities']['delete_published_posts']	= "delete_published_{$cap_type}s";
		$opts['capabilities']['edit_others_posts']		= "edit_others_{$cap_type}s";
		$opts['capabilities']['edit_post']				= "edit_{$cap_type}";
		$opts['capabilities']['edit_posts']				= "edit_{$cap_type}s";
		$opts['capabilities']['edit_private_posts']		= "edit_private_{$cap_type}s";
		$opts['capabilities']['edit_published_posts']	= "edit_published_{$cap_type}s";
		$opts['capabilities']['publish_posts']			= "publish_{$cap_type}s";
		$opts['capabilities']['read_post']				= "read_{$cap_type}";
		$opts['capabilities']['read_private_posts']		= "read_private_{$cap_type}s";

		$opts['labels']['add_new']						= esc_html__( "Add New {$single}", 'nutritionwp' );
		$opts['labels']['add_new_item']					= esc_html__( "Add New {$single}", 'nutritionwp' );
		$opts['labels']['all_items']					= esc_html__( $plural, 'nutritionwp' );
		$opts['labels']['edit_item']					= esc_html__( "Edit {$single}" , 'nutritionwp' );
		$opts['labels']['menu_name']					= esc_html__( "NutritionWP", 'nutritionwp' );
		$opts['labels']['name']							= esc_html__( $plural, 'nutritionwp' );
		$opts['labels']['name_admin_bar']				= esc_html__( $single, 'nutritionwp' );
		$opts['labels']['new_item']						= esc_html__( "New {$single}", 'nutritionwp' );
		$opts['labels']['not_found']					= esc_html__( "No {$plural} Found", 'nutritionwp' );
		$opts['labels']['not_found_in_trash']			= esc_html__( "No {$plural} Found in Trash", 'nutritionwp' );
		$opts['labels']['parent_item_colon']			= esc_html__( "Parent {$plural} :", 'nutritionwp' );
		$opts['labels']['search_items']					= esc_html__( "Search {$plural}", 'nutritionwp' );
		$opts['labels']['singular_name']				= esc_html__( $single, 'nutritionwp' );
		$opts['labels']['view_item']					= esc_html__( "View {$single}", 'nutritionwp' );

		$opts['rewrite']['ep_mask']						= EP_PERMALINK;
		$opts['rewrite']['feeds']						= FALSE;
		$opts['rewrite']['pages']						= TRUE;
		$opts['rewrite']['slug']						= esc_html__( strtolower( $plural ), 'nutritionwp' );
		$opts['rewrite']['with_front']					= FALSE;

		$opts = apply_filters( 'nutritionwp-cpt-options', $opts );
		
		register_post_type( strtolower( $cpt_name ), $opts );
	}
	
	/**
	 * Register the Taxonomies for the admin area.
	 * 
	 * @since    1.0.0
	 * @access	public
	 * @static
	 * @param	mixed $plural
	 * @param	mixed $single
	 * @param	mixed $tax_name
	 * @return	void
	 */
	public static function register_custom_taxonomy( $plural, $single, $tax_name ) {
		
		
		$opts['hierarchical']							= FALSE;
		$opts['public']									= TRUE;
		$opts['query_var']								= $tax_name;
		$opts['show_admin_column'] 						= FALSE;
		$opts['show_in_nav_menus']						= TRUE;
		$opts['show_tag_cloud'] 						= TRUE;
		$opts['show_ui']								= TRUE;
		$opts['sort'] 									= '';

		$opts['capabilities']['assign_terms'] 			= 'edit_posts';
		$opts['capabilities']['delete_terms'] 			= 'manage_categories';
		$opts['capabilities']['edit_terms'] 			= 'manage_categories';
		$opts['capabilities']['manage_terms'] 			= 'manage_categories';

		$opts['labels']['add_new_item'] 				= esc_html__( "Add New {$single}", 'nutritionwp' );
		$opts['labels']['add_or_remove_items'] 			= esc_html__( "Add or remove {$plural}", 'nutritionwp' );
		$opts['labels']['all_items'] 					= esc_html__( $plural, 'nutritionwp' );
		$opts['labels']['choose_from_most_used'] 		= esc_html__( "Choose from most used {$plural}", 'nutritionwp' );
		$opts['labels']['edit_item'] 					= esc_html__( "Edit {$single}" , 'nutritionwp');
		$opts['labels']['menu_name'] 					= esc_html__( $plural, 'nutritionwp' );
		$opts['labels']['name'] 						= esc_html__( $plural, 'nutritionwp' );
		$opts['labels']['new_item_name'] 				= esc_html__( "New {$single} Name", 'nutritionwp' );
		$opts['labels']['not_found'] 					= esc_html__( "No {$plural} Found", 'nutritionwp' );
		$opts['labels']['parent_item'] 					= esc_html__( "Parent {$single}", 'nutritionwp' );
		$opts['labels']['parent_item_colon'] 			= esc_html__( "Parent {$single}:", 'nutritionwp' );
		$opts['labels']['popular_items'] 				= esc_html__( "Popular {$plural}", 'nutritionwp' );
		$opts['labels']['search_items'] 				= esc_html__( "Search {$plural}", 'nutritionwp' );
		$opts['labels']['separate_items_with_commas'] 	= esc_html__( "Separate {$plural} with commas", 'nutritionwp' );
		$opts['labels']['singular_name'] 				= esc_html__( $single, 'nutritionwp' );
		$opts['labels']['update_item'] 					= esc_html__( "Update {$single}", 'nutritionwp' );
		$opts['labels']['view_item'] 					= esc_html__( "View {$single}", 'nutritionwp' );

		$opts['rewrite']['ep_mask']						= EP_NONE;
		$opts['rewrite']['hierarchical']				= FALSE;
		$opts['rewrite']['slug']						= esc_html__( strtolower( $plural ), 'nutritionwp' );
		$opts['rewrite']['with_front']					= FALSE;

		$opts = apply_filters( 'nutritionwp-taxonomy-options', $opts );

		register_taxonomy( $tax_name, 'nutritionwp-recipe', $opts );
		
	}
	
	/**
	 * Register the Taxonomies for the admin area.
	 * 
	 * @since	1.0.0
	 * @access	public
	 * @static
	 * @return	void
	 */
	public static function register_taxonomies() {
		
		Nutritionwp_Admin::register_custom_taxonomy( 'Courses', 'Course', 'nutritionwp-course');
		Nutritionwp_Admin::register_custom_taxonomy( 'Special Diets', 'Special Diet', 'nutritionwp-special-diet' );
		Nutritionwp_Admin::register_custom_taxonomy( 'Occasions', 'Occasion' , 'nutritionwp-occasion' );
		Nutritionwp_Admin::register_custom_taxonomy( 'Cuisines', 'Cuisine', 'nutritionwp-cuisine' );
		
		}
 
	/**
	 * Register the settings group for the admin area.
	 * 
	 * @since	1.0.0
	 * @access	public
	 * @static
	 * @return	void
	 */
	public static function register_settings() {

		register_setting('nwp_settings_group', 'nwp_settings');
	
	}

	/**
	 * Add the setting pages for the admin area.
	 *
	 * @since	1.0.0
	 * @access	public
	 * @static
	 * @return	void
	 */
	public static function add_menu_page() {
	
		add_submenu_page( 'edit.php?post_type=nutritionwp-recipe', 'NWP Settings', 'Settings', 'edit_pages', 'nwp-settings', 'nwp_render_settings'  );
		//add_submenu_page( 'edit.php?post_type=nutritionwp-recipe', 'NWP Pro', 'Upgrade to Pro', 'edit_pages', 'nwp-upgrade', 'nwp_upgrade'  );
	}
	
	
	/**
	 * Add admin columns.
	 * 
	 * @since	1.0.0
	 * @access	public
	 * @param	array $defaults
	 * @return	array $defaults
	 */
	public function add_admin_column( $defaults ) {
		
	    $defaults['nwp_shortcode'] = 'Recipe Shortcode';
	    
	    return $defaults;
	}
	
		 
	/**
	 * Add Admin Column Content
	 * 
	 * @since	1.0.0
	 * @access	public
	 * @param	string $column_name
	 * @param	int $post_ID
	 * @return	void
	 */
	public function add_admin_column_content( $column_name, $post_ID ) {
		
	    if ( $column_name == 'nwp_shortcode' ) {
	        
	        echo '<code> [nwp_recipe id=' . (int) $post_ID .'] </code>';
	      
	    }
	}
	/**
	 * Rename the excerpt to recipe description
	 * 
	 * @since	1.0.0
	 * @access	public
	 * @param	mixed $translation
	 * @param	mixed $original
	 * @return	void
	 */
	public function rename_excerpt_to_description( $translation, $original ) {
	
		global $post;
		
		if ( $post ) {
			
			if ( $post->post_type == "nutritionwp-recipe") {
				 
				if ( 'Excerpt' == $original ) {
				    
				    return 'Recipe Description';
				    
				} else {
					
				    $pos = strpos($original, 'Excerpts are optional hand-crafted summaries of your');
				    
				    if ($pos !== false) {
				        
				        return  '';
				        
				    }
				}
			}
		}	
		return $translation;
	}
	
	/**
	 * Callback for cmb2 serving type select
	 * 
	 * @access	public
	 * @static
	 * @param	mixed CMB2 $field
	 * @return	array
	 */
	public static function serving_type_cmb2_callback( $field ) {
		
		$serving_types = array(
			'Bar'		=> __( 'Bar', 'nutritionwp' ),
			'Bag'		=> __( 'Bag', 'nutritionwp' ),
			'Bottle'	=>__( 'Bottle', 'nutritionwp' ),
			'Bowl'		=> __( 'Bowl', 'nutritionwp' ),
			'Box'		=> __( 'Box', 'nutritionwp' ),
			'Can'		=> __( 'Can', 'nutritionwp' ),
			'Chip'		=> __( 'Chip', 'nutritionwp' ),
			'Container'	=> __( 'Container', 'nutritionwp' ),
			'Cookie'	=> __( 'Cookie', 'nutritionwp' ),
			'Cracker'	=> __( 'Cracker', 'nutritionwp' ),
			'Cube'		=> __( 'Cube', 'nutritionwp' ),
			'Cup'		=> __( 'Cup', 'nutritionwp' ),
			'Fluid Ounce (fl oz)'	=> __( 'Fluid Ounce (fl oz)', 'nutritionwp' ),
			'Gallon'	=> __( 'Gallon', 'nutritionwp' ),
			'Gram (g)'	=> __( 'Gram (g)', 'nutritionwp' ),
			'Item'		=> __( 'Item', 'nutritionwp' ),
			'Kilogram (kg)'	=> __( 'Kilogram (kg)', 'nutritionwp' ),
			'Liter'		=> __( 'Liter', 'nutritionwp' ),
			'Milligram (mg)'	=> __( 'Milligram (mg)', 'nutritionwp' ),
			'Milliliter (ml)'	=> __( 'Milliliter (ml)', 'nutritionwp' ),
			'Ounce (oz)'	=> __( 'Ounce (oz)', 'nutritionwp' ),
			'Package'	=> __( 'Package', 'nutritionwp' ),
			'Packet'	=> __( 'Packet', 'nutritionwp' ),
			'Plate'		=> __( 'Plate', 'nutritionwp' ),
			'Piece'		=> __( 'Piece', 'nutritionwp' ),
			'Pint'		=> __( 'Pint', 'nutritionwp' ),
			'Pound (lb)'	=> __( 'Pound (lb)', 'nutritionwp' ),
			'Quart'		=> __( 'Quart', 'nutritionwp' ),
			'Scoop'		=> __( 'Scoop', 'nutritionwp' ),
			'Serving'	=> __( 'Serving', 'nutritionwp' ),
			'Slice'		=> __( 'Slice', 'nutritionwp' ),
			'Stick'		=> __( 'Stick', 'nutritionwp' ),
			'Tablespoon (TBSP)'	=> __( 'Tablespoon (TBSP)', 'nutritionwp' ),
			'Teaspoon (tsp)'	=> __( 'Teaspoon (tsp)', 'nutritionwp' ),
			'Whole'		=> __( 'Whole', 'nutritionwp' ),
			
		);
		
		return $serving_types;
	
	}

	/**
	 * Register the Metaboxes for the admin area.
	 *
	 * @since	1.0.0
	 * @access	public
	 * @static
	 * @return	void
	 */
	public static function register_custom_meta_boxes() {
	
		$prefix = '_nwp_recipe_';
		
		$cmb = new_cmb2_box( array(
			'id'            => 'recipe_container',
			'title'         => __( 'Recipe', 'nutritionwp' ),
			'object_types'  => array( 'nutritionwp-recipe', ),
			'context'       => 'normal',
			'priority'      => 'high',
			'show_names'    => true,
		) );
		
		// Recipe Details Group
		$group_field_id = $cmb->add_field( array(
			'id'          => $prefix . 'details',
			'type'        => 'group',
			'description' => '',
			'repeatable'  => false,
			'options'     => array(
				'group_title'   => __( 'Details', 'nutritionwp' ),
			),
		) );

		// Serving Size
		$cmb->add_group_field( $group_field_id, array(
			'name'             => 'Serving Size',
			'desc'             => __( 'Must be a whole or decimal. ex. .125 = 1/8, .20 = 1/5, .25 = 1/2, .33 = 1/3, .5 = 1/2, .66 = 2/3, .75 = 3/4', 'nutritionwp' ),
			'id'               => 'serving_size',
			'type' => 'text_small',
			'attributes' => array(
					'type' => 'number',
					'pattern' => '\d*',
					'step'	=> '.01',
					'min' => '0',
					'max' => '500',
				)
		) );
				
		// Serving Type
		$cmb->add_group_field( $group_field_id, array(
			'name'             => 'Serving Type',
			'id'               => 'serving_type',
			'type'             => 'select',
			'show_option_none' => false,
			'default'          => 'Serving',
			'repeatable'       => false,
			'options_cb'	   => array( 'Nutritionwp_Admin', 'serving_type_cmb2_callback' )

		) );
		
		// Number of Serving Yield
		$cmb->add_group_field( $group_field_id, array(
			'name'             => 'Number of Servings',
			'desc'             => __( '(yield)', 'nutritionwp' ),
			'id'               => 'num_servings',
			'type' => 'text_small',
			'attributes' => array(
					'type' => 'number',
					'pattern' => '\d*',
					'min' => '0',
					'max' => '500',
				)
		) );
		
		// Prep Time
		$cmb->add_group_field( $group_field_id, array(
			'name' => __( 'Prep Time', 'nutritionwp' ),
			'desc' => __( '(minutes)', 'nutritionwp' ),
			'id'   => 'prep_time',
			'type' => 'text_small',
			'attributes' => array(
					'type' => 'number',
					'pattern' => '\d*',
					'min' => '0',
					'max' => '3000',
				)
		) );
		
		// Cook Time
		$cmb->add_group_field( $group_field_id, array(
			'name' => __( 'Cook Time', 'nutritionwp' ),
			'desc' => __( '(minutes)', 'nutritionwp' ),
			'id'   => 'cook_time',
			'type' => 'text_small',
			'attributes' => array(
					'type' => 'number',
					'pattern' => '\d*',
					'min' => '0',
					'max' => '3000',
				)
		) );
				
		// Source Link
		$cmb->add_group_field( $group_field_id, array(
			'name'             => __( 'Source', 'nutritionwp' ),
			'id'               => $prefix . 'source',
			'type'             => 'link_picker_text_nwp',
			'protocols' => array( 'http', 'https' ), // Array of allowed protocols

		) );
				
		// Ingredients
		$group_field_id = $cmb->add_field( array(
			'id'          => $prefix . 'ingredients',
			'type'        => 'group',
			'description' => '',
			'before_group'     => '<h3>Ingredients </h3>',
			'repeatable'  => true,
			'options'     => array(
				'group_title'   => __( 'Ingredient {#}', 'nutritionwp' ),
				'add_button'    => __( 'Add Ingredient', 'nutritionwp' ),
				'remove_button' => __( 'Remove Ingredient', 'nutritionwp' ),
				'sortable'      => true, 
			),
		) );
		
		// Ingredient Title
		$cmb->add_group_field( $group_field_id, array(
			'name'             => __( 'Ingredient Title', 'nutritionwp' ),
			'id'               => 'ingred_title',
			'type'             => 'text',
			'show_option_none' => true,
		) );
		
		
		// Ingredient Serving Size
		$cmb->add_group_field( $group_field_id, array(
			'name'             => __( 'Number of Servings', 'nutritionwp' ),
			'desc'             => __( 'Must be a whole or decimal. ex. .125 = 1/8, .20 = 1/5, .25 = 1/2, .33 = 1/3, .5 = 1/2, .66 = 2/3, .75 = 3/4', 'nutritionwp' ),
			'id'               => 'number_of_servings',
			'type' => 'text_small',
			'attributes' => array(
					'type' => 'number',
					'pattern' => '\d*',
					'step'	=> '.01',
					'min' => '0',
					'max' => '500',
				)
		) );
		
		// Ingredient Serving Type
		$cmb->add_group_field( $group_field_id, array(
			'name'             => __( 'Serving Type', 'nutritionwp' ),
			'id'               => 'serving_type',
			'type'             => 'select',
			'show_option_none' => false,
			'default'          => 'Serving',
			'repeatable'       => false,
			'options_cb'	   => array( 'Nutritionwp_Admin', 'serving_type_cmb2_callback' )
			)
		);		
		
		// Ingredient Link
		$cmb->add_group_field( $group_field_id, array(
			'name'             => __( 'Ingredient Link', 'nutritionwp' ),
			'id'               => 'ingred_link',
			'type'             => 'link_picker_nwp',
			'protocols' => array( 'http', 'https' ), // Array of allowed protocols

		) );
		
		// Directions
		$group_field_id = $cmb->add_field( array(
			'id'          => $prefix . 'directions',
			'type'        => 'group',
			'description' => '',
			'repeatable'  => true,
			'before_group'     => '<h3>Directions </h3>',
			'options'     => array(
				'group_title'   => __( 'Step {#}', 'nutritionwp' ),
				'add_button'    => __( 'Add Step', 'nutritionwp' ),
				'remove_button' => __( 'Remove Step', 'nutritionwp' ),
				'sortable'      => true,
			),
		) );
		
		// Direction Text
		$cmb->add_group_field( $group_field_id, array(
			'name'             => 'Text',
			'id'               => 'step_text',
			'type'             => 'textarea',
			'show_option_none' => true,
		) );
		
		// Direction Image
		$cmb->add_group_field( $group_field_id, array(
			'name'             => 'Photo',
			'id'               => 'step_image',
			'type'             => 'file_list',
			'show_option_none' => true,
			'allow' => array( 'attachment' ),
			'options' => array(
				'url' => false,
			),
			'text'    => array(
				'add_upload_files_text' => 'Add Image',
				'remove_image_text' => 'Remove Image',
			),
			'query_args' => array(
				'type' => array( 'image/jpeg', 'image/png' ),
			),
			
			'preview_size' => array( 150, 150 ),
		) );
	
		// Nutritional Information
		$group_field_id = $cmb->add_field( array(
			'id'          => $prefix . 'nutrition',
			'type'        => 'group',
			'description' => '',
			'repeatable'      => false,
			'options'     => array(
				'group_title'   => __( 'Nutrition Information', 'nutritionwp' ),
			),
		) );

		
		$nutritional_information_grams_1 = array('Total Fat' , 'Saturated Fat' , 'Monounsaturated Fat' , 'Polyunsaturated Fat' , 'Trans Fat' , 'Cholesterol' , 'Sodium' , 'Potassium' , 'Carbohydrate' , 'Dietary Fiber' , 'Sugar' , 'Protein');
		
		$nutritional_information_grams_2 = array('Carbohydrate' , 'Dietary Fiber' , 'Sugar' , 'Protein');
		
		$nutritional_information_mgrams = array('Cholesterol' , 'Sodium' , 'Potassium');

		$vitamins_minerals = array('Vitamin A' , 'Vitamin C' , 'Calcium' , 'Iron' , 'Vitamin D' , 'Vitamin E' , 'Vitamin K' , 'Thiamin' , 'Riboflavin B2' , 'Niacin' , 'Vitamin B6' , 'Folic Acid' , 'Folate', 'Vitamin B12' , 'Biotin' , 'Panthotenic Acid' , 'Phosphorus' , 'Iodine' , 'Magnesium' , 'Zinc' , 'Selenium' , 'Copper' , 'Manganese' , 'Chromium' , 'Molybdenum' , 'Chloride');
		
		$cmb->add_group_field( $group_field_id, array(
				'name'             => 'Calories',
				'id'               => sanitize_title( 'Calories' ),
				'type'             => 'text_small',
				'show_option_none' => true,
				'attributes' => array(
					'type' => 'number',
					'pattern' => '\d*',
					'min' => '0',
					'max' => '3000',
				)
			) );
			
		$cmb->add_group_field( $group_field_id, array(
				'name'             => 'Calories from Fat',
				'id'               => sanitize_title( 'Calories from Fat' ),
				'type'             => 'text_small',
				'show_option_none' => true,
				'attributes' => array(
					'type' => 'number',
					'pattern' => '\d*',
					'min' => '0',
					'max' => '3000',
				)
			) );	
		
		foreach ( $nutritional_information_grams_1 as $item ) {
			
			$cmb->add_group_field( $group_field_id, array(
				'name'             => $item,
				'description' => __( 'g', 'nutritionwp' ),
				'id'               => sanitize_title( $item ),
				'type'             => 'text_small',
				'show_option_none' => true,
				'attributes' => array(
					'type' => 'number',
					'pattern' => '\d*',
					'min' => '0',
					'max' => '3000',
				)
			) );
		}
		
		foreach ( $nutritional_information_mgrams as $item ) {
			
			$cmb->add_group_field( $group_field_id, array(
				'name'             => $item,
				'description' => __( 'mg', 'nutritionwp' ),
				'id'               => sanitize_title( $item ),
				'type'             => 'text_small',
				'show_option_none' => true,
				'attributes' => array(
					'type' => 'number',
					'pattern' => '\d*',
					'min' => '0',
					'max' => '3000',
				)
			) );
		}
		
		foreach ( $nutritional_information_grams_2 as $item ) {
			
			$cmb->add_group_field( $group_field_id, array(
				'name'             => $item,
				'description' => __( 'g', 'nutritionwp' ),
				'id'               => sanitize_title( $item ),
				'type'             => 'text_small',
				'show_option_none' => true,
				'attributes' => array(
					'type' => 'number',
					'pattern' => '\d*',
					'min' => '0',
					'max' => '3000',
				)
			) );
		}
		
		foreach ( $vitamins_minerals as $item ) {
			
			$cmb->add_group_field( $group_field_id, array(
				'name'             => $item,
				'description' => __( '%', 'nutritionwp' ),
				'id'               => sanitize_title( $item ),
				'type'             => 'text_small',
				'show_option_none' => true,
				'attributes' => array(
					'type' => 'number',
					'pattern' => '\d*',
					'min' => '0',
					'max' => '3000',
				)
			) );
		}
	}
	
	/**
	 * Add media button to post editor.
	 * 
	 * @since	1.0.0
	 * @access	public
	 * @return	void
	 */
	public function add_media_button() {

		 $title = __( 'Add Recipe', 'nutritionWP' );  ?>

	    <a id="nutritionwp-add-recipe" class="button" title="<?php echo esc_attr( $title ); ?>">
	        <span class="nwp-button-icon"></span> <?php echo esc_html( $title ); ?>
	    </a>
	
	    <style>
		    .nwp-button-icon {
			  background: transparent url(<?php echo esc_url( plugin_dir_url( __FILE__ ) . 'img/nutritionwp.png' ) ?>) no-repeat scroll 0 0;
			  width: 16px;
			  height: 16px;
			  display: inline-block;
			  vertical-align: text-top;
			  background-size: 16px;
	 		}
	    </style>
		<?php 
	}

	
	/**
	 * Render 'link_picker_nwp' custom field type
	 *
	 * @param array  $field              The passed in `CMB2_Field` object.
	 * @param mixed  $value              The value of this field escaped.
	 *                                   It defaults to `sanitize_text_field`.
	 *                                   If you need the unescaped value, you can access it
	 *                                   via `$field->value()`.
	 * @param int    $object_id          The ID of the current object.
	 * @param string $object_type        The type of object you are working with.
	 *                                   Most commonly, `post` (this applies to all post-types),
	 *                                   but could also be `comment`, `user` or `options-page`.
	 * @param object $field_type_object  The `CMB2_Types` object.
	 */
	public function cmb2_render_link_picker_nwp( $field, $value, $object_id, $object_type, $field_type_object ) {

		$value = wp_parse_args( $value, array(
			'url'   => '',
			'blank' => 'false',
		) );

		$blank_options  = '';
		$blank_options .= '<option value="false" ' . selected( $value['blank'], 'false', false ) . '>' . esc_html__( 'Opens in same', 'link-picker-for-cmb2' ) . '</option>';
		$blank_options .= '<option value="true" ' . selected( $value['blank'], 'true', false ) . '>' . esc_html__( 'Opens in new', 'link-picker-for-cmb2' ) . '</option>';
		?>
		<div class="link-picker">
			
			<div class="url">
				<p>
					<label for="<?php echo esc_attr( $field_type_object->_id( '_url' ) ); ?>'">
						<?php echo esc_html( $field_type_object->_text( 'link_picker_nwp_url', 'URL' ) ); ?>
					</label>
				</p>
				<?php
				echo wp_kses(
					$field_type_object->input(
						array(
							'class' => 'cmb_text_url',
							'name'  => esc_attr( $field_type_object->_name( '[url]' ) ),
							'id'    => esc_attr( $field_type_object->_id( '_url' ) ),
							'value' => esc_attr( $value['url'] ),
							'type'  => 'url',
							'desc'  => '',
						)
					),
					array(
						'input' => array(
							'type'     => array(),
							'class'    => array(),
							'name'     => array(),
							'id'       => array(),
							'value'    => array(),
							'disabled' => array(),
							'readonly' => array(),
						),
					)
				);
				?>
			</div>
			<div class="choose">
				<p>
					<label><?php esc_html_e( 'Choose', 'link-picker-for-cmb2' );?></label>
				</p>
				<button class="dashicons dashicons-admin-links js-insert-link button button-primary" title="<?php esc_html_e( 'Insert Link', 'link-picker-for-cmb2' ); ?>">
	 				<span class="screen-reader-text">
						<?php esc_html_e( 'Choose Link', 'link-picker-for-cmb2' ); ?>
					</span>
	 			</button>
			</div>
			<div class="blank">
				<p>
					<label for="<?php echo esc_attr( $field_type_object->_id( '_blank' ) ); ?>'">
						<?php echo esc_html( $field_type_object->_text( 'link_picker_nwp_blank', 'Window' ) ); ?>
					</label>
				</p>
				<?php
				echo wp_kses(
					$field_type_object->select(
						array(
							'class'   => 'cmb_checkbox',
							'name'    => esc_attr( $field_type_object->_name( '[blank]' ) ),
							'id'      => esc_attr( $field_type_object->_id( '_blank' ) ),
							'options' => wp_kses(
								$blank_options,
								array(
									'option' => array(
										'selected' => array(),
										'value'    => array(),
									),
								)
							),
							'desc'    => '',
						)
					),
					array(
						'select' => array(
							'class'    => array(),
							'name'     => array(),
							'id'       => array(),
							'disabled' => array(),
						),
						'option' => array(
							'selected' => array(),
							'value'    => array(),
						),
					)
				);
				?>
			</div>

		</div>
		<p class="clear">
			<?php
			echo wp_kses(
				$field_type_object->_desc(),
				array(
					'span' => array(
						'class' => array(),
					),
				)
			);
			?>
		</p>

		<?php
	}

	/**
	 * Render 'link_picker_text_nwp' custom field type
	 *
	 * @param array  $field              The passed in `CMB2_Field` object.
	 * @param mixed  $value              The value of this field escaped.
	 *                                   It defaults to `sanitize_text_field`.
	 *                                   If you need the unescaped value, you can access it
	 *                                   via `$field->value()`.
	 * @param int    $object_id          The ID of the current object.
	 * @param string $object_type        The type of object you are working with.
	 *                                   Most commonly, `post` (this applies to all post-types),
	 *                                   but could also be `comment`, `user` or `options-page`.
	 * @param object $field_type_object  The `CMB2_Types` object.
	 */
	public function cmb2_render_link_picker_text_nwp( $field, $value, $object_id, $object_type, $field_type_object ) {

		$value = wp_parse_args( $value, array(
			'text'  => '',
			'url'   => '',
			'blank' => 'false',
		) );

		$blank_options  = '';
		$blank_options .= '<option value="false" ' . selected( $value['blank'], 'false', false ) . '>' . esc_html__( 'Opens in same', 'link-picker-for-cmb2' ) . '</option>';
		$blank_options .= '<option value="true" ' . selected( $value['blank'], 'true', false ) . '>' . esc_html__( 'Opens in new', 'link-picker-for-cmb2' ) . '</option>';
		?>
		<div class="link-picker">
		
		<div class="text">
				<p>
					<label for="<?php echo esc_attr( $field_type_object->_id( '_text' ) ); ?>'">
						<?php echo esc_html( $field_type_object->_text( 'link_picker_nwp_text', 'Text' ) ); ?>
					</label>
				</p>
				<?php
				echo wp_kses(
					$field_type_object->input(
						array(
							'class' => 'cmb_text',
							'name'  => esc_attr( $field_type_object->_name( '[text]' ) ),
							'id'    => esc_attr( $field_type_object->_id( '_text' ) ),
							'value' => esc_attr( $value['text'] ),
							'desc'  => '',
						)
					),
					array(
						'input' => array(
							'type'     => array(),
							'class'    => array(),
							'name'     => array(),
							'id'       => array(),
							'value'    => array(),
							'disabled' => array(),
							'readonly' => array(),
						),
					)
				);
				?>
			</div>

			<div class="url">
				<p>
					<label for="<?php echo esc_attr( $field_type_object->_id( '_url' ) ); ?>'">
						<?php echo esc_html( $field_type_object->_text( 'link_picker_nwp_url', 'URL' ) ); ?>
					</label>
				</p>
				<?php
				echo wp_kses(
					$field_type_object->input(
						array(
							'class' => 'cmb_text_url',
							'name'  => esc_attr( $field_type_object->_name( '[url]' ) ),
							'id'    => esc_attr( $field_type_object->_id( '_url' ) ),
							'value' => esc_attr( $value['url'] ),
							'type'  => 'url',
							'desc'  => '',
						)
					),
					array(
						'input' => array(
							'type'     => array(),
							'class'    => array(),
							'name'     => array(),
							'id'       => array(),
							'value'    => array(),
							'disabled' => array(),
							'readonly' => array(),
						),
					)
				);
				?>
			</div>
			<div class="choose">
				<p>
					<label><?php esc_html_e( 'Choose', 'link-picker-for-cmb2' );?></label>
				</p>
				<button class="dashicons dashicons-admin-links js-insert-link button button-primary" title="<?php esc_html_e( 'Insert Link', 'link-picker-for-cmb2' ); ?>">
	 				<span class="screen-reader-text">
						<?php esc_html_e( 'Choose Link', 'link-picker-for-cmb2' ); ?>
					</span>
	 			</button>
			</div>
			<div class="blank">
				<p>
					<label for="<?php echo esc_attr( $field_type_object->_id( '_blank' ) ); ?>'">
						<?php echo esc_html( $field_type_object->_text( 'link_picker_nwp_blank', 'Window' ) ); ?>
					</label>
				</p>
				<?php
				echo wp_kses(
					$field_type_object->select(
						array(
							'class'   => 'cmb_checkbox',
							'name'    => esc_attr( $field_type_object->_name( '[blank]' ) ),
							'id'      => esc_attr( $field_type_object->_id( '_blank' ) ),
							'options' => wp_kses(
								$blank_options,
								array(
									'option' => array(
										'selected' => array(),
										'value'    => array(),
									),
								)
							),
							'desc'    => '',
						)
					),
					array(
						'select' => array(
							'class'    => array(),
							'name'     => array(),
							'id'       => array(),
							'disabled' => array(),
						),
						'option' => array(
							'selected' => array(),
							'value'    => array(),
						),
					)
				);
				?>
			</div>

		</div>
		<p class="clear">
			<?php
			echo wp_kses(
				$field_type_object->_desc(),
				array(
					'span' => array(
						'class' => array(),
					),
				)
			);
			?>
		</p>

		<?php
	}
	
	/**
	 * Optionally save the Link Picker values into separate fields
	 *
	 * @param  null   $override_value Sanitization override value to return.
	 *                                It is passed in as null, and is what we
	 *                                will modify to short-circuit
	 *                                CMB2's saving mechanism.
	 * @param  string $value          The actual field value.
	 * @param  int    $object_id      The id of the object you are working with. Most commonly, the post id.
	 * @param  array  $field_args     The field arguments.
	 * @return null                   The override value
	 */
	public function cmb2_sanitize_link_picker_nwp_split( $override_value, $value, $object_id, $field_args ) {
		if ( ! isset( $field_args['split_values'] ) || ! $field_args['split_values'] ) {
			// Don't do the override.
			return $override_value;
		}
		$link_picker_nwp_keys = array(
			//'text',
			'url',
			'blank',
		);
		foreach ( $link_picker_nwp_keys as $key ) {
			if ( ! empty( $value[ $key ] ) ) {
				update_post_meta( $object_id, $field_args['id'] . '_' . $key, $value[ $key ] );
			}
		}
	}

	/**
	 * The following snippets are required for allowing the address field
	 * to work as a repeatable field, or in a repeatable group
	 *
	 * @param  null   $check           Sanitization override value to return.
	 *                                 It is passed in as null, and is what we
	 *                                 will modify to short-circuit
	 *                                 CMB2's saving mechanism.
	 * @param  string $meta_value      The actual field value.
	 * @param  int    $object_id       The id of the object you are working with.
	 *                                 Most commonly, the post id.
	 * @param  array  $field_args      The field arguments.
	 * @param  object $sanitize_object This is an instance of the CMB2_Sanitize
	 *                                 object and gives you access to all of the
	 *                                 methods that CMB2 uses to sanitize its
	 *                                 field values.
	 * @return string                  The override value
	 */
	public function cmb2_sanitize_link_picker_nwp( $check, $meta_value, $object_id, $field_args, $sanitize_object ) {

		// if not repeatable, bail out.
		if ( ! is_array( $meta_value ) || ! $field_args['repeatable'] ) {
			return $check;
		}
		foreach ( $meta_value as $key => $val ) {
			$meta_value[ $key ] = null;
			if ( ! empty( $val['url'] ) ) {
				$meta_value[ $key ] = array_map( 'sanitize_text_field', $val );
			}
		}

		return $meta_value;
	}

	/**
	 * [cmb2_types_esc_link_picker_nwp description]
	 *
	 * @param  null   $check        Sanitization override value to return.
	 *                              It is passed in as null, and is what we
	 *                              will modify to short-circuit
	 *                              CMB2's saving mechanism.
	 * @param  string $meta_value   The actual field value.
	 * @param  array  $field_args   The field arguments.
	 * @param  object $field_object The field object.
	 * @return string               The override value
	 */
	public function cmb2_types_esc_link_picker_nwp( $check, $meta_value, $field_args, $field_object ) {

		// if not repeatable, bail out.
		if ( ! is_array( $meta_value ) || ! $field_args['repeatable'] ) {
			return $check;
		}
		foreach ( $meta_value as $key => $val ) {
			$meta_value[ $key ] = null;
			if ( ! empty( $val['url'] ) ) {
				$meta_value[ $key ] = array_map( 'esc_attr', $val );
			}
		}
		return $meta_value;
	}

	/**
	 * Render a placeholder wysiwyg box to allow dialogs to fire
	 */
	function render_placeholder_wysiwyg() {

		global $post;

		echo '<div class="hidden">';
		wp_editor( '', 'mkdo_lpfc_placeholder' );
		echo '</div>';

	}
}
	
