<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://rescuethemes.com
 * @since      1.0.0
 *
 * @package    Nutritionwp
 * @subpackage Nutritionwp/admin/partials
 */

function nwp_render_settings() {

	if ( ! current_user_can( 'manage_options' ) ) {
		return;
	}
	
	if ( isset( $_GET['settings-updated'] ) ) {
		 
		// Add settings saved message with the class of "updated"
		add_settings_error( 'nwp_messages', 'nwp_message', __( 'Settings Saved', 'nwp_domain' ), 'updated' );
	}
	 
	// Show error/update messages
	settings_errors( 'nwp_messages' );
	 
	// Retrieve our plugin settings from the options table
	$nwp_options = get_option('nwp_settings');
	
	ob_start(); ?>
	
	<div class="wrap">
		<h2>NutritionWP</h2>
		<form method="post" action="options.php">
 
			<?php settings_fields('nwp_settings_group'); ?>
			
			<h3><?php _e('Ingredients', 'nwp_domain'); ?></h3>
			
			<p>
				<label class="description" for="nwp_settings[ingreds_name]"><?php _e('Heading:', 'nwp_domain'); ?></label>
				<input id="nwp_settings[ingreds_name]" name="nwp_settings[ingreds_name]" type="text" value="<?php if ( $nwp_options['ingreds_name'] ) { echo esc_attr( $nwp_options['ingreds_name'] ); } else { echo _e('Ingredients', 'nwp_domain'); } ?>"/>
			</p>
			
			<h4><?php _e('Ingredient List Style', 'nwp_domain'); ?></h4>
			<?php $styles = array( 
						'Bulleted' => 'ul', 
						'Number' =>'ol'
					); ?>
			<select id="nwp_settings[ingred_list_style]" name="nwp_settings[ingred_list_style]"> 
				<?php foreach( $styles as $style => $value ) { ?> 
				<?php if ( $nwp_options['ingred_list_style'] == $value ) { $selected = 'selected="selected"'; } else { $selected = ''; } ?>
				<option value="<?php echo esc_attr( $value ); ?>" <?php echo esc_attr( $selected ); ?>><?php echo esc_attr( $style ); ?></option>
				<?php } ?> 
			</select>
			
			<hr>
			<h3><?php _e('Directions', 'nwp_domain'); ?></h3>
			<p>
				<label class="description" for="nwp_settings[directions_name]"><?php _e('Heading:', 'nwp_domain'); ?></label>
				<input id="nwp_settings[directions_name]" name="nwp_settings[directions_name]" type="text" value="<?php if ( $nwp_options['directions_name'] ) { echo esc_attr( $nwp_options['directions_name'] ); } else { echo _e('Directions', 'nwp_domain'); } ?>"/>
			</p>
			<h4><?php _e('Directions List Style', 'nwp_domain'); ?></h4>
			
			<?php $styles = array( 
						'Number' =>'ol', 
						'Bulleted' => 'ul' 
					); ?>
					
			<select id="nwp_settings[directions_list_style]" name="nwp_settings[directions_list_style]"> 
				<?php foreach( $styles as $style => $value ) { ?> 
				<?php if ( $nwp_options['directions_list_style'] == $value ) { $selected = 'selected="selected"'; } else { $selected = ''; } ?>
				<option value="<?php echo esc_attr( $value ); ?>" <?php echo esc_attr( $selected ); ?>><?php echo esc_attr( $style ); ?></option>
				<?php } ?> 
			</select>
			<hr>
			<h3><?php _e('Advanced', 'nwp_domain'); ?></h3>
			<h4><?php _e('Disable NutritionWP CSS', 'nwp_domain'); ?></h4>
			<p>
				<input id="nwp_settings[enable_css]" type="checkbox" name="nwp_settings[enable_css]" value="1" <?php checked('1', $nwp_options['enable_css']); ?>  />
				<label class="description" for="nwp_settings[enable_css]"><?php _e('Check to disable plugin CSS', 'nwp_domain'); ?></label>
			</p>		
			<?php submit_button( 'Save Settings' ); ?>
 		
		</form>
	</div>	
	<p>
		Upgrade to <a href="https://rescuethemes.com/wordpress-plugins/nutritionwp-pro/">NutritionWP Pro</a> for more features and support!
	</p>
	<?php 
	echo ob_get_clean();
}