<?php

class NWP_Recipe extends NWP_Post {

	protected static $post_type = 'nutritionwp-recipe';

	/**
	 * Get the ID for the user who created this recipe
	 *
	 * @since	1.0.0
	 * @access	public
	 * @return	int
	 */
	public function get_user_id() {
		return (int) $this->get_field( 'post_author' );
	}

	
	/**
	 * Get the recipe's description.
	 * 
	 * @since	1.0.0
	 * @access	public
	 * @return  string 
	 */
	public function get_description() {
		
		return apply_filters('nwp_filter_get_summary', $this->get_excerpt() );
	}
	
	/**
	 * Get the recipe's image ID
	 * @since	1.0.0
	 * @access	public
	 * @return  int
	 */
	public function get_image_id() {
		return $this->get_featured_image_id();
	}

	/**
	 * Get the prep time for this recipe
	 *
	 * @since	1.0.0
	 * @access	public
	 * @return  string
	 */
	public function get_prep_time() {
		return (int) $this->get_recipe_details( 'prep_time' );
	}

	/**
	 * Get the cook time for this recipe
	 *
	 * @since	1.0.0
	 * @access	public
	 * @return  string
	 */
	public function get_cook_time() {
		return (int) $this->get_recipe_details( 'cook_time' );
	}

	/**
	 * Get the serving size for this recipe
	 *
	 * @since	1.0.0
	 * @access	public
	 * @return  string
	 */
	public function get_serving_size() {
		return nwp_format_number( $this->get_recipe_details( 'serving_size' ));
	}

	/**
	 * Get the number of servings for this recipe
	 *
	 * @since	1.0.0
	 * @access	public
	 * @return  string
	 */
	public function get_number_of_servings() {
		return nwp_format_number( $this->get_recipe_details( 'num_servings' ) );
	}

	/**
	 * Get the serving type for this recipe
	 *
	 * @since	1.0.0
	 * @access	public
	 * @return  string
	 */
	public function get_serving_type() {
		return $this->get_recipe_details( 'serving_type' );
	}

	/**
	 * Get the source for this recipe
	 *
	 * @since	1.0.7
	 * @access	public
	 * @return  string
	 */
	public function get_source() {
		return $this->get_recipe_details( '_nwp_recipe_source' );
	}

	/**
	 * Get the directions for this recipe
	 *
	 * @since	1.0.0
	 * @access	public
	 * @return  string
	 */
	public function get_directions() {
		return $this->get_meta( '_nwp_recipe_directions' );
	}

	/**
	 * Get the ingredients for this recipe
	 *
	 * @since	1.0.0
	 * @access	public
	 * @return  array
	 */
	public function get_ingredients() {
		
		return $this->get_meta( '_nwp_recipe_ingredients' );
		
	}

	/**
	 * Get the nutrition for this recipe
	 *
	 * @since	1.0.0
	 * @access	public
	 * @return  string
	 */
	public function get_nutrition() {
		return $this->get_meta( '_nwp_recipe_nutrition' );
	}
	
	
	/**
	 * Get course for this recipe
	 *
	 * @since	1.0.0
	 * @access	public
	 * @return  array
	 */
	public function get_courses() {
		
		if ( $courses = $this->get_taxonomy_terms( 'nutritionwp-course' ) ) {
			
			$return_array = array();
			
			foreach( $courses as $cat ) {
				$return_array[] = $cat->name;
			}
			return $return_array;

		} else {
			return array();
		}
	}

	/**
	 * Get special diet for this recipe
	 *
	 * @since	1.0.0
	 * @access	public
	 * @return  array
	 */
	public function get_special_diets() {
		
		if ( $special_diets = $this->get_taxonomy_terms( 'nutritionwp-special-diet' ) ) {
			$return_array = array();
			
			foreach( $special_diets as $cat ) {
				$return_array[] = $cat->name;
			}
			return $return_array;
		} else {
			return array();
		}
	}

	/**
	 * Get occasion for this recipe
	 *
	 * @since	1.0.0
	 * @access	public
	 * @return  array
	 */
	public function get_occasions() {
		
		if ( $occasions = $this->get_taxonomy_terms( 'nutritionwp-occasion' ) ) {
			$return_array = array();
			
			foreach( $occasions as $cat ) {
				$return_array[] = $cat->name;
			}
			return $return_array;
		} else {
			return array();
		}
	}

	/**
	 * Get cuisine for this recipe
	 *
	 * @since	1.0.0
	 * @access	public
	 * @return  array
	 */
	public function get_cuisines() {
		
		if ( $cuisines = $this->get_taxonomy_terms( 'nutritionwp-cuisine' ) ) {
			$return_array = array();
			
			foreach( $cuisines as $cat ) {
				$return_array[] = $cat->name;
			}
			return $return_array;
		} else {
			return array();
		}
	}
	/**
	 * Get metadata details stored about this recipe
	 *
	 * @since	1.0.0
	 * @access	public
	 * @return  mixed
	 */
	private function get_recipe_details( $key ) {
		
		$metadata = $this->get_meta( '_nwp_recipe_details' );
		if ( ! empty( $metadata[0][ $key ] ) ) {
			return $metadata[0][ $key ];
		} else {
			return '';
		}
	}
	

}
