<?php 
/**
 * Template tags for details.
 *
 * @since 1.0.0
 *
 */

/**
 * Takes in a type and converts to int or float
 *
 * @since	1.0.0
 * @param	int or float
 * @returns	int or float
 */
function nwp_format_number( $number ) {
  
   if ( !is_numeric( $number ) ) return 0;
   
   // Return an int or float if it is a number
   return $number + 0;  
}

/**
 * This formats the nutrition label number
 * 
 * @since	1.0.0
 * @access	public
 * @param	bool $value (default: false)
 * @return	int or float
 */
function nwp_format_food_value ( $value = false ) {
	if ( !$value ) {
		return 0;
	} else {
		return $value;
	}
} 


/**
 * Formats daily value of macros according to usda recommendations
 * 
 * @since	1.0.0
 * @access	public
 * @param	bool $value (default: false)
 * @param	bool $food_item_name (default: false)
 * @return	void
 */
function nwp_format_daily_value ( $value = false, $food_item_name = false) {
	
	if ( $value && $food_item_name ) {
		
		$recommended_number = 0;
		
		if ( $food_item_name == "total-fat" ) { $recommended_number = 65; }
		if ( $food_item_name == "saturated-fat" ) { $recommended_number = 20; }
		if ( $food_item_name == "cholesterol" ) { $recommended_number = 300; }
		if ( $food_item_name == "sodium" ) { $recommended_number = 2400; }
		if ( $food_item_name == "potassium" ) { $recommended_number = 3500; }
		if ( $food_item_name == "carbohydrate" ) { $recommended_number = 300; }
		if ( $food_item_name == "fiber" ) { $recommended_number = 25; }						
		if ( $food_item_name == "protein" ) { $recommended_number = 50; }

		
		if ( $recommended_number ) {
			$recommended_value = ( $value / $recommended_number ) * 100;
			if ( $recommended_value < 1 ) {
				$recommended_value = round($recommended_value, 0);
			} 
			return $recommended_value;
		} else {
			return 0;
		}
		
	} else {
		return 0;
	}
	
} 