<?php 
/**
 * Template tags for ingredients.
 *
 * @since 1.0.0
 *
 */


function nwp_get_ingredients( $args = array() ) {

	$ingredients = $recipe->get_ingredients( $args );

	/**
	 * Filter the array of ingredients.
	 *
	 * @since 1.0.0
	 *
	 * @param array $ingredients
	 */
	$ingredients = apply_filters( 'nwp_get_ingredients', $ingredients );

	return $ingredients;
}
	


/**
 * Get the ingredients Heading.
 * 
 * @return string $ingredients_name
 */
function nwp_get_ingredients_heading() {

	$ingredients_name = get_option( 'nwp_settings' )['ingreds_name'];
	
	if ( !$ingredients_name ) {
		
		$ingredients_name = __( 'Ingredients', 'nutritionWP' );
		
	} 
	/**
	 * Filter the Ingredients heading.
	 *
	 * @since 1.0.0
	 *
	 * @param string $ingredients_name
	 */
	$ingredients_name = apply_filters( 'nwp_ingredients_header_name', $ingredients_name );

	return $ingredients_name;
}

/**
 * Get the ingredients list style.
 *
 * @since 1.0.0
 *
 * @return string $style
 */
function nwp_get_ingredients_list_style() {

	$style = get_option( 'nwp_settings' )['ingred_list_style'];

	if ( !$style ) {
		$style = 'ul';
	}
	
	return $style;

}


/**
 * Formats decimal as fractions.
 * 
 * @since	1.0.0
 * @access	public
 * @param	mixed $decimal_servings_size
 * @return	string $servings_nicename
 */
function nwp_get_serving_nicename( $decimal_servings_size) {

	$servings_size = explode( '.', esc_attr($decimal_servings_size));
    $servings_whole = $servings_size[0];

	if ( $servings_whole == 0 ) { $servings_whole = ''; }
		if ( isset( $servings_size[1] ) ) {		
			switch ( $servings_size[1] ) {
				case 125:
					$servings_fraction = '1/8';
					break;
				case 2:
				case 20:
					$servings_fraction = '1/5';
					break;
				case 250:
				case 25:	
					$servings_fraction = '1/4';
					break;
				case 330:
				case 33:
					$servings_fraction = '1/3';
					break;
				case 500:
				case 5:
					$servings_fraction = '1/2';
					break;
				case 660:
				case 66:
					$servings_fraction = '2/3';
					break;
				case 750:
				case 75:
					$servings_fraction = '3/4';
					break;
				case 99:
					$servings_fraction = '1';
					break;	
				case 000:
					$servings_fraction = '';
					break;			
				default:
					return $decimal_servings_size;
					break;
			}
		}
		
		$servings_nicename = $servings_whole . ' ' . $servings_fraction;
		return $servings_nicename;
}

	