<?php

/**
 * Basic Recipe Template
 *
 *
 * @link       https://rescuethemes.com
 * @since      1.0.0
 *
 * @package    Nutritionwp
 */
 

// Create Recipe object
$recipe = NWP_Recipe::get_by_post_id( get_the_ID() );

// Get Recipe meta
$ingredients = $recipe->get_ingredients();	
$directions = $recipe->get_directions();
$nutrition = $recipe->get_nutrition();

// Get Terms
$course_terms = get_the_terms( get_the_ID(), 'nutritionwp-course' );
$occasions_terms = get_the_terms( get_the_ID(), 'nutritionwp-occasion' );
$special_diet_terms = get_the_terms( get_the_ID(), 'nutritionwp-special-diet' );
$cuisines_terms = get_the_terms( get_the_ID(), 'nutritionwp-cuisine' );

?>

<div class="nwp-recipe">

 		<?php do_action('nwp_before_recipe_details');
 		
	 		// Display title and featured image of recipe if it is a shortcode
	 		
	 		if ( !is_singular('nutritionwp-recipe') ) { 
	 			
	 			// Get title 
	 			?>
	 			<h2 class="fn" itemprop="name"><?php echo get_the_title(); ?></h2>

				<?php 
					
				// Get featured image
				 if ( $recipe->get_image_id() ) {
		
					$image = wp_get_attachment_image_src( $recipe->get_image_id() , 'nwp-recipe-medium' ); ?>
			
					<img itemprop="image" class="photo" alt="<?php the_title(); ?>" src="<?php echo esc_url( $image[0] ); ?>">
			
				<?php } 


 			} ?>
 			<span class="nwp-recipe-author">by 
 				<a itemprop="author" class="author" itemscope itemtype="http://schema.org/Person" href="<?php echo esc_url( get_author_posts_url( $recipe->get_user_id() ) );?>">
					<span itemprop="name">
						<?php echo get_the_author(); ?> 
					</span>
				</a>
			</span>
			
		 	<div class="nwp-details">
			 	
			 	<div itemprop="description" class="description" > 
				 	<?php echo esc_html( $recipe->get_description() ); ?> 
			 	</div>
			 	
			    <ul class="recipe-meta">
				 <li><strong> <?php _e('Serving Size : ','nutritionpwp');?></strong> 
						<span><?php echo esc_attr( nwp_get_serving_nicename( $recipe->get_serving_size() ) ); echo ' ' . esc_attr__( $recipe->get_serving_type(), 'nutritionWP' ); ?> </span>
				 </li>	
			     
			     <li itemprop="recipeYield" class="yield"><strong> <?php  _e('Servings Per Recipe : ','nutritionpwp');?></strong>
			     	<span><?php echo esc_attr( nwp_get_serving_nicename( $recipe->get_number_of_servings() ) ); ?></span>
			     </li>

				
				<?php if ( $recipe->get_prep_time() ) {
				
					do_action('nwp_before_prep_time'); ?>	
				
				 <li> 
				 	<time itemprop="prepTime" class="prepTime" datetime="PT<?php echo esc_attr( $recipe->get_prep_time() ); ?>M" >
				 		<strong><?php  _e('Prep time : ','nutritionpwp');?></strong>
				 		<span class="value-title" ><?php echo (int) $recipe->get_prep_time() ?><?php  _e(' Minutes', 'nutritionpwp'); ?></span>
				 	</time>
				 </li>
				 
				 <?php do_action('nwp_after_prep_time');
			     
			     } ?> 
			     	
			     <?php if ( $recipe->get_cook_time() ) {
				     
			     	do_action('nwp_before_cook_time'); ?>		
			     	
					 <li> 
					 	<time itemprop="cookTime" class="cookTime" datetime="PT<?php echo esc_attr( $recipe->get_cook_time() ); ?>M" >
					 		<strong><?php  _e('Cook time : ','nutritionpwp');?></strong>
					 		<span class="value-title" ><?php echo (int) $recipe->get_cook_time() ?> <?php  _e(' Minutes', 'nutritionpwp'); ?></span>
					 	</time>
					 </li>	
					 
					 <?php do_action('nwp_after_cook_time');
				} ?>  
				
				 <span class="duration">
				 	<time itemprop="totalTime" class="value-title" datetime="PT<?php echo (int) ( $recipe->get_prep_time() + $recipe->get_cook_time() ); ?>M"></time>
				 </span>	
				 
				 <?php if ( $recipe->get_source() ) {
				     $source = $recipe->get_source();
				     $blank = esc_attr( $source['blank'] );
    	    		 $target =  $blank == 'true' ? '_blank' : '_self';
				     
			     	do_action('nwp_before_source'); ?>		
			     	
					 <li> 
					 		<strong><?php  _e('Source : ','nutritionpwp');?></strong>
					 		<span class="source" ><?php echo '<a href="'  . esc_url( $source['url'] ) . '" target="' . $target .'">' . esc_attr( $source['text'] ) . '</a>';?></span>
					 </li>	
					 
					 <?php do_action('nwp_after_source');
				} ?>  
				</ul>	 
				
				<?php do_action('nwp_before_categories'); ?>  
				
				<ul class="recipe-categories">	
					
				<?php 	
				    if ( $cuisines_terms && ! is_wp_error( $cuisines_terms ) )  { ?>
					     <li class='cuisines'>
					     	<strong><?php echo __('Cuisine : ', 'nutritionpwp'); ?></strong>
					     <?php echo get_the_term_list( get_the_ID(), 'nutritionwp-cuisine', '', ', ', '');
					     echo "</li>"; 
					 }
					if ( $special_diet_terms && ! is_wp_error( $special_diet_terms ) )  {  ?>
					     <li class='special-diet'>
					     	<strong><?php echo __('Special diet : ', 'nutritionpwp'); ?></strong>
					     <?php echo get_the_term_list( get_the_ID(), 'nutritionwp-special-diet', '', ', ', '');
					     echo "</li>";
					 }
			        if ( $course_terms && ! is_wp_error( $course_terms ) )  {  ?>
					     <li class='course'>
					     <strong><?php echo __('Course : ', 'nutritionpwp'); ?></strong>
					     <?php echo get_the_term_list( get_the_ID(), 'nutritionwp-course', '', ', ', '');
					     echo "</li>"; 
					 }
					if ( $occasions_terms && ! is_wp_error( $occasions_terms ) )  {  ?>
					     <li class='occasions'>
					     <strong><?php echo __('Occasion : ', 'nutritionpwp'); ?></strong>
					     <?php echo get_the_term_list( get_the_ID(), 'nutritionwp-occasion', '', ', ', '');
					     echo "</li>";
					}
			    ?>
			    
			   </ul> <!-- recipe-categories -->
			   
			   <?php do_action('nwp_after_categories'); ?>
			   
		 	</div>  <!-- nwp-details -->
		 	
		 	<?php do_action('nwp_after_recipe_details'); ?>
		 	
	<hr></hr> 
   
   <?php do_action('nwp_before_ingredients'); ?>
     	
   <div class="nwp-ingredients">	
	   
   <h3><?php echo esc_attr( nwp_get_ingredients_heading() ); ?></h3>
    
    <?php
    
	 if ( $ingredients ) {    

    ?>
    
    <<?php echo esc_attr( nwp_get_ingredients_list_style() ); ?>>
    
    	<?php foreach ( $ingredients as $ingredient ) { ?>
    	    
    	    	<li itemprop="ingredients" class="ingredient">
    	    		<?php  if ( ! $ingredient['ingred_link']['url'] ) { ?>
    	    		
    	    		 	<strong><?php echo esc_attr( nwp_get_serving_nicename( $ingredient['number_of_servings'] ) ) . ' ' .  esc_attr( $ingredient['serving_type'] ) . '</strong>' . ' ' . esc_attr( $ingredient['ingred_title'] ); ?>

    	    		 	<?php } else {
    	    		 	$blank = esc_attr( $ingredient['ingred_link']['blank'] );
    	    		 	$target =  $blank == 'true' ? '_blank' : '_self';
    	    		 	 ?>
    	    		 	<strong><?php echo esc_attr( nwp_get_serving_nicename( $ingredient['number_of_servings'] ) ) . ' ' .  esc_attr( $ingredient['serving_type'] ) . '</strong> <a href="'  . esc_url( $ingredient['ingred_link']['url'] ) . '" target="' . $target .'">' . esc_attr( $ingredient['ingred_title'] ) . '</a>' ?>

    	    			<?php } // endif url?>
	   	    	</li>
		    	 
		<?php } ?>
    </<?php echo esc_attr( nwp_get_ingredients_list_style() ); ?>>
    
    <?php } else { ?>
    
    	<p><?php _e( 'This recipe currently has no ingredients', 'nutritionWP' ); ?> .</p>
    
    <?php } ?>
    
	</div> <!-- nwp-ingredients -->
	
	<?php do_action('nwp_after_ingredients'); ?>
	
    <hr></hr>    
    
   <?php do_action('nwp_before_directions'); ?>
   
   <div class="nwp-directions" itemprop="recipeInstructions">
	   
   <h3><?php echo esc_attr( nwp_get_directions_heading() ); ?></h3>
    		    
	      	<?php if ( $directions ) { ?> 
	      	
	      			<<?php echo esc_attr( nwp_get_directions_list_style() ); ?>>
	      			
		      	<?php foreach ( $directions as $direction ) { ?>
		      	
			  		<li>	
			  		
			      		<?php echo wp_kses_post( $direction['step_text'] ) ;
	
			      		if ( !empty( $direction['step_image'] ) ) { ?>
				      		<div class="steps-images">
				      		<?php foreach ( $direction['step_image'] as $image_id => $image_url ) { 
						  		echo '<a href="' . esc_url( $image_url )  . '" target="_blank">';
			      				echo wp_get_attachment_image( $image_id, 'thumbnail', false, array( 'class' => 'step-image', ) ); 
				  				echo '</a>';
				  			} ?>
				  			</div> 
			      		<?php } ?>
		      		
			  		</li>
			  		
			  	<?php } ?>
			  	
	      			</<?php echo esc_attr( nwp_get_directions_list_style() ); ?>>
	      			
		    <?php } else { ?>
			    
			    <p><?php _e( 'This recipe currently has no directions', 'nutritionWP' ); ?></p> 
			     
			     <?php } ?>
	    	
   </div> <!-- nwp-directions -->
   
   <?php do_action('nwp_after_directions');
   
   if ( isset( $nutrition[0]['calories'] ) ) {
		
		do_action('nwp_before_nutrition'); ?>
		
		  <div itemprop="nutrition" itemscope itemtype="http://schema.org/NutritionInformation" class="nwp-nutrition-label">
		      <div class="heading textcentered"><?php _e( 'Nutrition Facts', 'nutritionWP' ); ?> </div>
		        <div>
			       <span itemprop="servingSize"><?php _e( 'Serving Size', 'nutritionWP' ); ?>  <?php echo esc_attr( nwp_get_serving_nicename( $recipe->get_serving_size() ) ); echo ' ' . esc_attr__( $recipe->get_serving_type(), 'nutritionWP' ); ?> </span>
			   </div>
		       <div><?php _e('Servings Per Recipe', 'nutritionWP' ); ?> <?php echo esc_attr( nwp_get_serving_nicename( $recipe->get_number_of_servings() ) ); ?></div>
		   
		         <hr />
		        <div class="amount-per-serving small item_row noborder"><?php _e( 'Amount Per Serving', 'nutritionWP' ); ?></div>
		         <div class="food-macro-row">
		         	<span itemprop="calories" class="nwp-left"><strong><?php _e( 'Calories', 'nutritionWP' ); ?></strong> <?php echo esc_attr(nwp_format_food_value($nutrition[0]['calories'])); ?></span>
		         	<span class="nwp-right"><?php _e( 'Calories from Fat', 'nutritionWP' ); ?> <?php echo esc_attr(nwp_format_food_value($nutrition[0]['calories-from-fat']));?> </span>
		         </div>
		        <div class="food-macro-row daily-value small"><?php _e( '% Daily Value *', 'nutritionWP' ); ?></div>
		         
		          <div class="food-macro-row">
			        <span itemprop="fatContent" class="nwp-left"><strong><?php _e( 'Total Fat', 'nutritionWP' ); ?></strong>  <?php echo esc_attr(nwp_format_food_value($nutrition[0]['total-fat'][0])) ?>g</span>
			        <span class="nwp-right"> <?php echo esc_attr(round(nwp_format_daily_value($nutrition[0]['total-fat'], 'total-fat'))); ?>%</span>
			      </div>
			     <div class="food-macro-row">
		          <span itemprop="saturatedFatContent" class="nwp-left indent"><?php _e( 'Saturated Fat', 'nutritionWP' ); ?> <?php echo esc_attr(nwp_format_food_value($nutrition[0]['saturated-fat'])); ?>g</span>
		          <span class="nwp-right"><?php echo esc_attr(round(nwp_format_daily_value($nutrition[0]['saturated-fat'], 'saturated_fat'))); ?>%</span>
		        </div>
		        <div class="food-macro-row indent">
		          <span class="nwp-left"><?php _e( 'Polyunsaturated Fat', 'nutritionWP' ); ?> <?php echo esc_attr(nwp_format_food_value($nutrition[0]['polyunsaturated-fat'])); ?>g</span>
		        </div>
		        <div class="food-macro-row indent">
		          <span class="nwp-left"><?php _e( 'Monounsaturated Fat', 'nutritionWP' ); ?> <?php echo esc_attr(nwp_format_food_value($nutrition[0]['monounsaturated-fat'])); ?>g</span>
		        </div>
		
		        <div class="food-macro-row indent">
		          <span itemprop="transFatContent" class="nwp-left"><?php _e( 'Trans Fat', 'nutritionWP' ); ?> <?php echo esc_attr(nwp_format_food_value($nutrition[0]['trans-fat'])); ?>g</span>
		        </div> 
		        <div class="food-macro-row">
		          <span itemprop="cholesterolContent" class="nwp-left"><strong><?php _e( 'Cholesterol', 'nutritionWP' ); ?></strong> <?php echo esc_attr(nwp_format_food_value($nutrition[0]['cholesterol'])); ?>g</span>
		          <span class="nwp-right"><?php echo esc_attr(round(nwp_format_daily_value($nutrition[0]['cholesterol'], 'cholesterol'))); ?>%</span>
		        </div>
		        <div class="food-macro-row">
		          <span itemprop="sodiumContent" class="nwp-left"><strong><?php _e( 'Sodium', 'nutritionWP' ); ?></strong> <?php echo esc_attr(nwp_format_food_value($nutrition[0]['sodium'])); ?>mg</span>
		          <span class="nwp-right"><?php echo esc_attr(round(nwp_format_daily_value($nutrition[0]['sodium'], 'sodium'))); ?>%</span>
		       </div>
		       <div class="food-macro-row">
		         <span class="nwp-left"><strong><?php _e( 'Potassium', 'nutritionWP' ); ?></strong> <?php echo esc_attr(nwp_format_food_value($nutrition[0]['potassium'])); ?>mg</span>
		          <span class="nwp-right"><?php echo esc_attr(round(nwp_format_daily_value($nutrition[0]['potassium'], 'potassium'))); ?>%</span>
		       </div>
		       <div class="food-macro-row">
		          <span itemprop="carbohydrateContent" class="nwp-left"><strong><?php _e( 'Total Carbohydrate', 'nutritionWP' ); ?></strong> <?php echo esc_attr(nwp_format_food_value($nutrition[0]['carbohydrate'])); ?>g</span>
		          <span class="nwp-right"><?php echo esc_attr(round(nwp_format_daily_value($nutrition[0]['carbohydrate'], 'carbohydrate'))); ?>%</span>
		       </div>
		       <div class="food-macro-row indent">
		          <span itemprop="fiberContent" class="nwp-left"><?php _e( 'Dietary Fiber', 'nutritionWP' ); ?> <?php echo esc_attr(nwp_format_food_value($nutrition[0]['dietary-fiber'])); ?>g</span>
		          <span class="nwp-right"><?php echo esc_attr(round(nwp_format_daily_value($nutrition[0]['dietary-fiber'], 'fiber'))); ?>%</span>
		       </div>
		        <div class="food-macro-row indent">
		          <span itemprop="sugarContent" class="nwp-left"><?php _e( 'Sugars', 'nutritionWP' ); ?> <?php echo esc_attr(nwp_format_food_value($nutrition[0]['sugar'])); ?>g</span>
		         
		        </div>  
		       <div class="food-macro-row">
		       	  <span itemprop="proteinContent" class="nwp-left"><strong><?php _e( 'Protein', 'nutritionWP' ); ?></strong> <?php echo esc_attr(nwp_format_food_value($nutrition[0]['protein']));  ?>g</span>
		          <span class="nwp-right"><?php echo esc_attr(round(nwp_format_daily_value($nutrition[0]['protein'], 'protein'))); ?>%</span>
		        </div>
		        <hr />
		        <?php
		        
		        $vitamins_minerals = array(
		        	__( 'Vitamin A', 'nutritionWP' ), 
		        	__( 'Vitamin C', 'nutritionWP' ), 
		        	__( 'Calcium', 'nutritionWP' ), 
		        	__( 'Iron', 'nutritionWP' ), 
		        	__( 'Vitamin D', 'nutritionWP' ), 
		        	__( 'Vitamin E', 'nutritionWP' ), 
		        	__( 'Vitamin K', 'nutritionWP' ), 
		        	__( 'Thiamin', 'nutritionWP' ), 
		        	__( 'Riboflavin B2', 'nutritionWP' ), 
		        	__( 'Niacin', 'nutritionWP' ), 
		        	__( 'Vitamin B6', 'nutritionWP' ), 
		        	__( 'Folic Acid', 'nutritionWP' ), 
		        	__( 'Folate', 'nutritionWP' ), 
		        	__( 'Vitamin B12', 'nutritionWP' ), 
		        	__( 'Biotin', 'nutritionWP' ), 
		        	__( 'Panthotenic Acid', 'nutritionWP' ), 
		        	__( 'Phosphorus', 'nutritionWP' ), 
		        	__( 'Iodine', 'nutritionWP' ), 
		        	__( 'Magnesium', 'nutritionWP' ), 
		        	__( 'Zinc', 'nutritionWP' ), 
		        	__( 'Selenium', 'nutritionWP' ), 
		        	__( 'Copper', 'nutritionWP' ), 
		        	__( 'Manganese', 'nutritionWP' ), 
		        	__( 'Chromium', 'nutritionWP' ), 
		        	__( 'Molybdenum', 'nutritionWP' ), 
		        	__( 'Chloride', 'nutritionWP' )
		        );
		        
		        foreach ( $vitamins_minerals as $item ) {
		
				      if ( nwp_format_food_value( $nutrition[0][sanitize_title( $item )] ) > 0 ) {  ?>
			      
						   <div class="food-vitamin-row">
						      <span class="nwp-left"><?php echo esc_attr( $item ); ?></span>
						      <span class="nwp-right"><?php echo (int) ( $nutrition[0][sanitize_title( $item )] ) ?>%</span>
						   </div>
			        <?php }
				} ?>
		      
		       <div class="dv small">
		         <?php echo __("Percent Daily Values are based on a 2,000 calorie diet. Your daily values may be higher or lower depending on your calorie needs."); ?>
		       </div>  <!-- dv small -->
		</div> <!-- nwp-nutrition-label -->
		
		<?php do_action('nwp_after_nutrition');
	} ?>	
		
</div> <!-- nwp-recipe -->